<?php
/**
 * PMC Builder functions
 *
**/
if(class_exists('AQ_Page_Builder')) {
	
	/** 
	 * Core functions
	*******************/
	 
	/* Register a block */
	function aq_register_block($block_class) {
		global $aq_registered_blocks;
		$aq_registered_blocks[strtolower($block_class)] = new $block_class;
	}
	
	/** Un-register a block **/
	function aq_unregister_block($block_class) {
		global $aq_registered_blocks;
		$block_class = strtolower($block_class);
		foreach($aq_registered_blocks as $block) {
			if($block->id_base == $block_class) unset($aq_registered_blocks[$block_class]);
		}
	}
	
	/** Get list of all blocks **/
	function aq_get_blocks($template_id) {
		global $aq_page_builder;
		$blocks = $aq_page_builder->get_blocks($template_id);
		
		return $blocks;
	}
	function aq_resize( $url, $width, $height = null, $crop = null, $single = true ) {
		//validate inputs
		if(!$url OR !$width ) return false;
		//define upload path & dir
		$upload_info = wp_upload_dir();
		$upload_dir = $upload_info['basedir'];
		$upload_url = $upload_info['baseurl'];
		//check if $img_url is local
		if(strpos( $url, $upload_url ) === false) return false;
		//define path of image
		$rel_path = str_replace( $upload_url, '', $url);
		$img_path = $upload_dir . $rel_path;
		//check if img path exists, and is an image indeed
		if( !file_exists($img_path) OR !getimagesize($img_path) ) return false;
		//get image info
		$info = pathinfo($img_path);
		$ext = $info['extension'];
		list($orig_w,$orig_h) = getimagesize($img_path);
		//get image size after cropping
		$dims = image_resize_dimensions($orig_w, $orig_h, $width, $height, $crop);
		$dst_w = $dims[4];
		$dst_h = $dims[5];
		//use this to check if cropped image already exists, so we can return that instead
		$suffix = "{$dst_w}x{$dst_h}";
		$dst_rel_path = str_replace( '.'.$ext, '', $rel_path);
		$destfilename = "{$upload_dir}{$dst_rel_path}-{$suffix}.{$ext}";
		if(!$dst_h) {
			//can't resize, so return original url
			$img_url = $url;
			$dst_w = $orig_w;
			$dst_h = $orig_h;
		}
		//else check if cache exists
		elseif(file_exists($destfilename) && getimagesize($destfilename)) {
			$img_url = "{$upload_url}{$dst_rel_path}-{$suffix}.{$ext}";
		} 
		//else, we resize the image and return the new resized image url
		else {
			// Note: This pre-3.5 fallback check will edited out in subsequent version
			if(function_exists('wp_get_image_editor')) {
				$editor = wp_get_image_editor($img_path);
				if ( is_wp_error( $editor ) || is_wp_error( $editor->resize( $width, $height, $crop ) ) )
					return false;
				$resized_file = $editor->save();
				if(!is_wp_error($resized_file)) {
					$resized_rel_path = str_replace( $upload_dir, '', $resized_file['path']);
					$img_url = $upload_url . $resized_rel_path;
				} else {
					return false;
				}
			} else {
				$resized_img_path = image_resize( $img_path, $width, $height, $crop ); // Fallback foo
				if(!is_wp_error($resized_img_path)) {
					$resized_rel_path = str_replace( $upload_dir, '', $resized_img_path);
					$img_url = $upload_url . $resized_rel_path;
				} else {
					return false;
				}
			}
		}
		//return the output
		if($single) {
			//str return
			$image = $img_url;
		} else {
			//array return
			$image = array (
				0 => $img_url,
				1 => $dst_w,
				2 => $dst_h
			);
		}
		return $image;
	}	
	/** 
	 * Form Field Helper functions
	 *
	 * Provides some default fields for use in the blocks
	********************************************************/
	
	/* Input field - Options: $size = min, small, full */
	function aq_field_input($field_id, $block_id, $input, $size = 'full', $type = 'text') {
		$output = '<input type="'.$type.'" id="'. $block_id .'_'.$field_id.'" class="input-'.$size.'" value="'.$input.'" name="aq_blocks['.$block_id.']['.$field_id.']">';
		
		return $output;
	}
	
	/* Textarea field */
	function aq_field_textarea($field_id, $block_id, $text, $size = 'full') {
		$output = '<textarea id="'. $block_id .'_'.$field_id.'" class="textarea-'.$size.'" name="aq_blocks['.$block_id.']['.$field_id.']" rows="5">'.$text.'</textarea>';
		
		return $output;
	}
	
	
	/* Select field */
	function aq_field_select($field_id, $block_id, $options, $selected) {
		$options = is_array($options) ? $options : array();
		$output = '<select id="'. $block_id .'_'.$field_id.'" name="aq_blocks['.$block_id.']['.$field_id.']">';
		foreach($options as $key=>$value) {
			$output .= '<option value="'.$key.'" '.selected( $selected, $key, false ).'>'.htmlspecialchars($value).'</option>';
		}
		$output .= '</select>';
		
		return $output;
	}
	
	/* Multiselect field */
	function aq_field_multiselect($field_id, $block_id, $options, $selected_keys = array()) {
		$output = '<select id="'. $block_id .'_'.$field_id.'" multiple="multiple" class="select of-input" name="aq_blocks['.$block_id.']['.$field_id.'][]">';
		foreach ($options as $key => $option) {
			$selected = (is_array($selected_keys) && in_array($key, $selected_keys)) ? $selected = 'selected="selected"' : '';			
			$output .= '<option id="'. $block_id .'_'.$field_id.'_'. $key .'" value="'.$key.'" '. $selected .' />'.$option.'</option>';
		}
		$output .= '</select>';
		
		return $output;
	}
	
	/* Color picker field */
	function aq_field_color_picker($field_id, $block_id, $color, $default = '') {
		$output = '<div class="aqpb-color-picker">';
			$output .= '<input type="text" id="'. $block_id .'_'.$field_id.'" class="input-color-picker" value="'. $color .'" name="aq_blocks['.$block_id.']['.$field_id.']" data-default-color="'. $default .'"/>';
		$output .= '</div>';
		
		return $output;
	}
	
	/* Single Checkbox */
	function aq_field_checkbox($field_id, $block_id, $check) {
		$output = '<input type="hidden" name="aq_blocks['.$block_id.']['.$field_id.']" value="0" />';
		$output .= '<input type="checkbox" id="'. $block_id .'_'.$field_id.'" class="input-checkbox" name="aq_blocks['.$block_id.']['.$field_id.']" '. checked( 1, $check, false ) .' value="1"/>';
		
		return $output;
	}
	
	/* Multi Checkbox */
	function aq_field_multicheck($field_id, $block_id, $fields = array(), $selected = array()) {
	
	}
	
	/* Media Uploader */
	function aq_field_upload($field_id, $block_id, $media, $media_type = '') {
		$output = '<input type="text" id="'. $block_id .'_'.$field_id.'" class="input-full input-upload" value="'.$media.'" name="aq_blocks['.$block_id.']['.$field_id.']">';
		$output .= '<a href="#" class="aq_upload_button button" rel="'.$media_type.'">Upload</a><p></p>';
		
		return $output;
	}
	
	/** 
	 * Misc Helper Functions
	**************************/
	
	/** Get column width
	 * @parameters - $size (column size), $grid (grid size e.g 940), $margin
	 */
	function aq_get_column_width($size, $grid = 940, $margin = 20) {
		
		$columns = range(1,12);
		$widths = array();
		foreach($columns as $column) {
			$width = (( $grid + $margin ) / 12 * $column) - $margin;
			$width = round($width);
			$widths[$column] = $width;
		}
		
		$column_id = absint(preg_replace("/[^0-9]/", '', $size));
		$column_width = $widths[$column_id];
		return $column_width;
	}
	
	/** Recursive sanitize
	 * For those complex multidim arrays 
	 * Has impact on server load on template save, so use only where necessary 
	 */
	function aq_recursive_sanitize($value) {
		if(is_array($value)) {
			$value = array_map('aq_recursive_sanitize', $value);
		} else {
			$value = htmlspecialchars(stripslashes($value));
		}
		return $value;
	}
	
	function pmc_inner_block($content,$instance,$title,$icon){
		$rand = rand(100,999);
		echo '<div id="template-block-'.$rand.'" class="description prebuild ">',
				'<dl class="block-bar">',
					'<dt class="block-handle">',
						'<div class="block-title">',
							'<i class="fa '.$icon.' " style="color:FFF"></i>'.$title.
						'</div>',
						'<span class="block-controls">',
							'<a class="block-edit inner" id="edit-'.$rand.'" title="Edit Block" href="#block-settings-'.$rand.'">Edit Block</a>',
						'</span>',
					'</dt>',
				'</dl>',
				'<div class="block-settings cf" id="block-settings-'.$rand.'">';
				$content -> form($instance);
		echo '</div>',
			'</div>';
		
	}
	/* function for portfolio block*/
	function pmc_portBlock($title,$number_post,$rowsB,$categories,$port_ajax,$id,$show_navigation = 1){
		wp_enqueue_script('pmc_bxSlider');		
		global $pmc_data;
		if(isset($pmc_data['home_recent_number_post'])){
			$showpost = $pmc_data['home_recent_number_post'] ;}
		else{
			$showpost = 3;}
			
		if($number_post){
			$showpost = $number_post  ;}		
		if($title) {
			$title = $title;
		}
		else {
			$title = '';
		}
			
		if(isset($pmc_data['home_recent_number_display']))
			$rows = $pmc_data['home_recent_number_display'];
		else
			$rows = 3;
			
		if($rowsB){
			$rows = $rowsB;
		}	
		
		if($categories)
			$categories = $categories;
		else
			$categories='';
			
			$pc = new WP_Query(array('post_type' => $pmc_data['port_slug'],
					'tax_query' => array( 
						 array (
						  'taxonomy' => 'portfoliocategory',
						  'field' => 'id',
						  'terms' => $categories
						 ), 
					 ),
					'posts_per_page' => $number_post)
				 );
	
	?>
		<script type="text/javascript">
		jQuery(document).ready(function($){
			jQuery('.sliderAdvertisePort').bxSlider({
			  auto: true,
			  speed: 1000,
			  <?php if($show_navigation == 0){ ?>
			  controls: false,
			  <?php } ?>
			  pause: 8000,
			  pager :false,
				prevText : '<i class="fa fa-angle-left"></i>',
				nextText : '<i class="fa fa-angle-right"></i>',
			  easing : 'easeInOutQuint',
			});
		});	
		</script>
		
	<?php 	
	if ($pc->have_posts()) :
	wp_enqueue_script('pmc_bxSlider');	?>
	<div class="homerecent">
		<div class="homerecentInner">
		<div id = "showpost-<?php echo $pmc_data['port_slug'] ?>">
			<div class="showpostload"><div class="loading"></div></div>
			<div class = "closehomeshow-<?php echo $pmc_data['port_slug'] ?> port closeajax"><i class="fa fa-times"></i></div>
			<div class="showpostpostcontent"></div>
		</div>	
		<ul id="sliderAdvertisePort" class="sliderAdvertisePort">
			<?php
			$currentindex = '';
			$count = 1;
			$countitem = 1;
			$type = $pmc_data['port_slug'];
			?>
			<?php  while ($pc->have_posts()) : $pc->the_post();
			if($countitem == 1){
				echo '<li>';}			
			$full_image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'homePort', false);	
			$catType= 'portfoliocategory';
			
			//category
			$categoryIn = get_the_term_list( get_the_ID(), $catType, '', ', ', '' );	
			$category = explode(',',$categoryIn);	
			//end category			
			if ( has_post_thumbnail() ){
				$image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'homePort', false);
				$image = $image[0];
				$image_big = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'homePortBig', false);
				
				$image_big = $image_big[0];
				$imagefull = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'full', false);
				$imagefull = $imagefull[0];			
				}
			?>
				<div class="one_third <?php if($countitem == 2) echo 'big' ?> <?php if($countitem == 4) echo 'first'; ?>" >
				
					<?php if ($port_ajax == 'true'){ ?>
					<div class="click" id="<?php echo $type ?>_<?php echo get_the_id() ?>">
					<?php } ?>
						<div class="recentimage">
							<div class="overdefult">
							
								<div class="recentdescription">
									<?php if ($port_ajax != 'true'){ ?>
										<a href = "<?php echo get_permalink( get_the_id()) ?>" title="<?php echo esc_attr(  get_the_title(get_the_id()) ) ?>"  >
									<?php } ?>
									<h3><?php the_title() ?></h3>
									<?php if ($port_ajax != 'true'){ ?>
										</a>
									<?php } ?>	
									<div class="home-portfolio-categories"><?php echo strip_tags(get_the_term_list( get_the_ID(), 'portfoliocategory', '', ', ', '' )); ?></div>
								</div>
								
							</div>	
		
							<div class="image">
									
									<?php if ($port_ajax != 'true'){ ?>
										<a href = "<?php echo get_permalink( get_the_id()) ?>" title="<?php echo esc_attr(  get_the_title(get_the_id()) ) ?>"  >
									<?php } ?>										
									<?php if (isset($image)){ ?>
										<?php if($countitem == 2) { ?>
											<img class="portfolio-home-image" src="<?php echo $image_big ?>" alt="<?php the_title(); ?>">
										<?php } else { ?>
										
											<img class="portfolio-home-image" src="<?php echo $image ?>" alt="<?php the_title(); ?>">
										
										<?php } ?>	
									<?php } else  { ?>	
										<img class="portfolio-home-image" src="http://placehold.it/393x300" alt="<?php the_title(); ?>">
									<?php } ?>	
									<?php if ($port_ajax != 'true'){ ?>
										</a>
									<?php } ?>	
							</div>
						</div>
				
					<?php if ($port_ajax == 'true'){ ?>	
					</div>
					<?php } ?>
				</div>
			<?php 
			$count++;
			
			 if($countitem == 5){ 
				$countitem = 0; ?>
				</li>
			<?php } 
			$countitem++;
			endwhile; 
			wp_reset_query(); ?>
			</ul>
		</div>
	</div>
	<?php  endif; ?>
	<div class="clear"></div>
	<?php
	}	
	/*portfolio loop*/
	function pmc_portfolio($portSize, $item, $post = 'port' ,$number = 0,$cat = '',$port_ajax, $style = 'default',$title = 1, $excerpt = 1,$home = '',$masonry = 0, $related_port = '', $infinite = 0,$paged_in = 1,$lightbox = 0){
		wp_enqueue_script('pmc_isotope');		
		global $pmc_data; 
		$categport = '';
		$paged = (get_query_var('paged')) ? get_query_var('paged') : $paged_in;
		if($post == 'port'){
			$postT = $pmc_data['port_slug'];
			$postC = 'portfoliocategory';
			$showPost = $pmc_data['port_slug'];
		} else {
			$postT = 'post';
			$postC = 'category';	
			$showPost = 'post';
		}
		
		if(isset($infinite) && $infinite == 1){
			//$number = -1;
		}
			
		if($cat != ''){	
				$args = array(
				'tax_query' => array(array('taxonomy' => $postC,'field' => 'id','terms' => $cat)),
				'showposts'     => $number,
				'post_type' => $postT,
				'paged'    => $paged,
				'post__not_in' => array(get_the_id())
				);	
		
			}
		else{
				$args = array(
				'showposts'     => $number,
				'post_type' => $postT,
				'paged'    => $paged,
				'post__not_in' => array(get_the_id())
				);
			}
		query_posts( $args );

		if($item == 4){
			$columns = 'one_fourth';
			$image_width = 'port4';
			$limit = 20;
			$img_par = ' width="280px" height="220px" ';
			$video_width = '280';
			$video_height = '220';
		}
		if($item == 3){
			$columns = 'one_third';
			if($home == 'homePort'){
				$image_width = 'homePort';
			} else {
				$image_width = 'port3';
			}
			$limit = 26;
			$img_par = ' width="380px" height="300px" ';
			$video_width = '380';
			$video_height = '300';			
		}	
		if($item == 2){
			$columns = 'one_half';
			$image_width = 'port2';
			$limit = 35;
			$img_par = ' width="570px" height="450px" ';
			$video_width = '570';
			$video_height = '450';			
		}

		if(isset($style) && $style == 'circle'){
			$image_width = 'port-circle';
			$img_par = ' width="275px" height="275px" ';			
		}

		$new_class = 'homePort';
		if($home != 'homePort'){
			$new_class =  'pagePort'; 	
		} else{
			$img_par = ' width="393px" height="300px" ';
			$video_width = '393';
			$video_height = '300';				
		}
		
		
		$masonry_pmc = '';
		if($masonry == 1){
			$masonry_pmc =  'masonry_pmc'; 
		} 		
		$currentindex = $linkPost = '';
		$currentindex = '';
		$count = 1;
		$countitem = 1;

		?>
		<div class="homerecent <?php echo $new_class ?>">
		<div class="homerecentInner <?php echo $style ?>">
		<div id = "showpost-<?php echo $showPost ?>">
			<div class="showpostload"><div class="loading"></div></div>
			<div class = "closehomeshow-<?php echo $showPost ?> <?php echo $post ?> closeajax"><i class="fa fa-times"></i></div>
			<div class="showpostpostcontent"></div>
		</div>	
		<div class="portfolio">	
			<div id="portitems4">
					<?php
					while ( have_posts() ) : the_post();
						$postmeta = get_post_custom(get_the_ID()); 
						$imagefull = $image = '';
							
						$do_not_duplicate = get_the_ID(); 
						if ( has_post_thumbnail() ){
							$image = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), $image_width , false);
							$image = $image[0];
							
							$imagefull = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'full', false);
							$imagefull = $imagefull[0];		
						
							}
						$full_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full', false);
						$entrycategory = get_the_term_list( get_the_ID(), $postC, '', ',', '' );
						$catstring = $entrycategory;
						$catstring = strip_tags($catstring);
						$catidlist = explode(",", $catstring);
						$catlist = '';
						for($i = 0; $i < sizeof($catidlist); ++$i){
							$catidlist[$i].=$currentindex;
							$find =     array("&", "/", " ","amp;","&#38;");
							$replace  = array("", "", "", "","");			
							$catlist .= str_replace($find,$replace,$catidlist[$i]). ' ';
							
						}
						$categoryIn = get_the_term_list( get_the_ID(), $postC, '', ', ', '' );	
						$category = explode(',',$categoryIn);	
						if ( has_post_format( 'link' , get_the_ID()) and $post == 'post') {
							if(isset($postmeta["link_post_url"][0] )) $linkPost = $postmeta["link_post_url"][0];
							}
						else{
							if (function_exists('icl_object_id')) 
								$linkPost = get_permalink(icl_object_id(get_the_ID(), $pmc_data['port_slug'], true, true));
							else 
								$linkPost = get_permalink();
						}		
						
						if($count != ($item+1)){
							echo '<div class="'.$columns.' item'.$item.' '.$catlist .' '.$masonry_pmc.'" data-category="'. $catlist.'" >';							
						}
						else{
							echo '<div class="'.$columns.' last item'.$item.' '.$catlist .' '.$masonry_pmc.'" data-category="'. $catlist.'" >';
							$count = 0;
						}
						if($lightbox == 1){
							$link = 'href = "'.$imagefull . '" rel="lightbox"';
							$link_title = '';
						}else if(isset($postmeta["out_link"][0] ) && $postmeta['out_link'][0] == 1){
							$link = 'href = "'.$postmeta['website_url'][0].'" target = "_blank"';
							$link_title = 'href = "'.$postmeta['website_url'][0].'" target = "_blank"';							
						}
						else {
							$link = 'href = "'.get_permalink( get_the_id()).'" ';
							$link_title = 'href = "'.get_permalink( get_the_id()).'" ';						
						}
												


						
						?>
								<?php if ($port_ajax == 'true' && !has_post_format( 'link' , get_the_id())){ ?>
								<div class="click" id="<?php echo $showPost ?>_<?php echo get_the_id() ?>">
								<?php } ?>
			
									<div class="recentimage">
										<?php if ($port_ajax != 'true' || has_post_format( 'link' , get_the_id())){ ?>
											<?php if (has_post_format( 'link' , get_the_id())) { ?>
												<a href = "<?php echo $postmeta["link_post_url"][0] ?>" title="<?php echo esc_attr(  get_the_title(get_the_id()) ) ?>"  >
											<?php } else { ?>
												<a <?php echo $link ?> title="<?php echo esc_attr(  get_the_title(get_the_id()) ) ?>"  >
											<?php } ?>
										<?php } ?>		
										<?php if (!isset($postmeta['show_video'][0]) || $postmeta['show_video'][0] != 1) {?>	
										<div class="overdefult">
										
											<div class="recentdescription">
										
												<?php if($home == 'homePort'){ ?>
													<h3><?php the_title() ?></h3>													
													<div class ="border-line"></div>
													<div class="home-portfolio-categories"><?php echo strip_tags(get_the_term_list( get_the_ID(), $postC, '', ', ', '' )); ?></div>
												<?php } else {?>
													<?php if($masonry != 1){ ?>
														<div class="home-portfolio-categories pagePort"><?php echo strip_tags(get_the_term_list( get_the_ID(), $postC, '', ', ', '' )); ?></div>
													<?php } ?>
												<?php } ?>								
											</div>
										</div>	
										<?php } ?>
										<?php if ($port_ajax != 'true' || has_post_format( 'link' , get_the_id())){ ?>
											</a>
										<?php } ?>										
										<div class="image">
											<?php if ($port_ajax != 'true' || has_post_format( 'link' , get_the_id())){ ?>
												<?php if (has_post_format( 'link' , get_the_id())){ ?>
													<a href = "<?php echo $postmeta["link_post_url"][0] ?>" title="<?php echo esc_attr(  get_the_title(get_the_id()) ) ?>"  >
												<?php } else { ?>
													<?php if (isset($image) && ($postmeta['show_video'][0] == 0 || !isset($postmeta['show_video'][0]))){ ?>
														<a <?php echo $link ?> title="<?php echo esc_attr(  get_the_title(get_the_id()) ) ?>"  >
													<?php } ?>
												<?php } ?>
											<?php } ?>		
											<?php if(isset($postmeta['show_video'][0]) && $postmeta['show_video'][0] && $style != 'circle') {
												$video_arg  = array('width'=>$video_width,'height'=>$video_height);
												$video = wp_oembed_get( $postmeta['video'][0], $video_arg );		
												$video = preg_replace('/width=\"(\d)*\"/', 'width="'.$video_width.'"', $video);			
												$video = preg_replace('/height=\"(\d)*\"/', 'height="'.$video_height.'"', $video);
												echo $video;	
											} ?>
											<?php if (!empty($image) && ($postmeta['show_video'][0] == 0 || !isset($postmeta['show_video'][0]))){ ?>
												<?php if($countitem == 2) { ?>
													<img class="portfolio-home-image" src="<?php echo $imagefull ?>" alt="<?php the_title(); ?> <?php echo $img_par ?>">
												<?php } else { ?>
												
													<img class="portfolio-home-image" src="<?php echo $image ?>" alt="<?php the_title(); ?>" <?php echo $img_par ?>>
												
												<?php } ?>	
											<?php } ?>	
											<?php if ($port_ajax != 'true'){ ?>
												<?php if (isset($image) && ($postmeta['show_video'][0] == 0 || !isset($postmeta['show_video'][0]))){ ?>
													</a>
												<?php } ?>
											<?php } ?>	
										</div>
									</div>								

									<div class="port-meta">
									<?php if($related_port == ''){ ?>
									<?php if($title == 1) { ?>
										<?php if ($port_ajax != 'true' || has_post_format( 'link' , get_the_id())){ ?>
											<?php if (has_post_format( 'link' , get_the_id())){ ?>
												<a href = "<?php echo $postmeta["link_post_url"][0] ?>" title="<?php echo esc_attr(  get_the_title(get_the_id()) ) ?>"  >
											<?php } else { ?>
												<a <?php echo $link_title ?> title="<?php echo esc_attr(  get_the_title(get_the_id()) ) ?>"  >
											<?php } ?>
										<?php } ?>									
										<div class="port-meta title"><?php the_title() ?></div>
										<?php if ($port_ajax != 'true' || has_post_format( 'link' , get_the_id())){ ?>
											</a>
										<?php } ?>	
									<?php } ?>		
									<?php if($masonry == 1){ ?>
										<div class="home-portfolio-categories pagePort"><?php echo strip_tags(get_the_term_list( get_the_ID(), $postC, '', ', ', '' )); ?></div>
									<?php } ?>								
									<?php if($excerpt == 1) { ?>
										<div class="port-meta excerpt"><?php echo excerpt($limit); ?> </div>
									<?php } ?>
									<?php if ($post == 'post' && $masonry == 1){?> <a class="masonry-blog-link" href = "<?php echo get_permalink( get_the_id()) ?> " ><?php _e('Read more','pmc-themes'); ?></a><?php } ?>
									<?php } ?>
									</div>
								<?php if ($port_ajax == 'true' && !has_post_format( 'link' , get_the_id())){ ?>	
								</div>
								<?php } ?>
							</div>
						<?php 
						$count++;		
						
					endwhile; ?>
					<?php if($infinite == 1 && !is_home()){ ?>
						<div class="navigation-pmc"><p><?php posts_nav_link(); ?></p></div>
					<?php } ?>
				</div>
				
			<?php 
			if($home != 'homePort' && $infinite != 1){
			if(!function_exists('wp_pagenavi')) { 
				get_template_part('includes/wp-pagenavi');
				wp_pagenavi(); 
			}else{
				wp_pagenavi();
	
			}
			}
			wp_reset_query();
			?>			
			</div>			
		</div>
		</div>
		<?php
	}	
	
	add_action('save_post', 'pmc_update_post_builder');
	add_action("admin_init", "pmc_builder_add_meta_box");
	
	function pmc_builder_add_meta_box(){
		add_meta_box("pmc_post_custom_top_content", "Custom post top and bottom content", "pmc_post_builder_content", "post", "normal", "high");
		add_meta_box("pmc_post_custom_top_content", "Custom post top and bottom content", "pmc_post_builder_content", "portfolio", "normal");
		add_meta_box("pmc_page_builder_content", "PMC page builder options for this page", "pmc_page_builder_content", "page", "normal");			
		
	}	
	
	function pmc_remove_revslider_metaboxes(){
		 remove_meta_box( 'mymetabox_revslider_0', 'page' , '' ); 
		 remove_meta_box( 'mymetabox_revslider_0', 'post' , '' ); 
	}
	add_action( 'do_meta_boxes', 'pmc_remove_revslider_metaboxes' );
	
	function pmc_page_builder_content(){	
		global $post;	
		$pmc_data = get_post_custom(get_the_id());		
		if (isset($pmc_data["page_builder"][0])){		
		$page_builder = $pmc_data["page_builder"][0];	
		}else{		
		$page_builder = "";	}	
		if (isset($pmc_data["custom_post_footer"][0])){		
			$custom_post_footer = $pmc_data["custom_post_footer"][0];	
		}else{		
			$custom_post_footer = "";	
		}	
		if (isset($pmc_data["custom_post_top"][0])){		
			$custom_post_top = $pmc_data["custom_post_top"][0];	
		}else{		
			$custom_post_top = "";	
		}			
		?>    
  
 
		<table cellpadding="15" cellspacing="0">
			<tr>            	
			<td><label>Page Builder Template (choose the template made in Page Builder to display on this Page. You need to set Template for Page Builder Template from Page Atributes.): </label>
			<br>				
				<select id="page_builder" name="page_builder">				
				<option value="none">None</option>				
				<?php							
				$args = array( 'numberposts' => -1,'post_type' => 'template');				
				$posts = get_posts($args);
				foreach( $posts as $post ) : setup_postdata($post); ?>
				<option value="<?php echo get_the_id(); ?>" <?php if(get_the_id() == $page_builder) echo 'selected'; ?>><?php the_title(); ?></option>
				<?php endforeach; ?>				
				</select>
			</td>           
			</tr>		
			<tr>            	
			<td><label>Custom Header for this Page (choose any template to be displayed as this Page's Header. If nothing is choosen, default header will be used.) : </label>				
			<br>		
				<select id="custom_post_top" name="custom_post_top">				
				<option value="none">Default</option>	
				<option value="empty" <?php if($custom_post_top == 'empty') echo 'selected'; ?>>Empty</option>				
				<?php						
				$args = array( 'numberposts' => -1,'post_type' => 'template');				
				$posts = get_posts($args);								
				foreach( $posts as $post ) : setup_postdata($post); ?>						
				<option value="<?php echo get_the_id(); ?>" <?php if(get_the_id() == $custom_post_top) echo 'selected'; ?>><?php the_title(); ?></option>				
				<?php endforeach; ?>				
				</select>
			</td>            
			</tr>			
			<tr>            	
			<td><label>Custom Footer for this Page (choose any template to be displayed as this Page's Footer. If nothing is choosen, default footer will be used.) : </label>				
			<br>				
				<select id="custom_post_footer"  name="custom_post_footer">				
				<option value="none">Default</option>
				<option value="empty" <?php if($custom_post_footer == 'empty') echo 'selected'; ?>>Empty</option>					
				<?php							
				$args = array( 'numberposts' => -1,'post_type' => 'template');				
				$posts = get_posts($args);								
				foreach( $posts as $post ) : setup_postdata($post); ?>						
				<option value="<?php echo get_the_id(); ?>" <?php if(get_the_id() == $custom_post_footer) echo 'selected'; ?>>
				<?php the_title(); ?>
				</option>				
				<?php endforeach; ?>				
				</select>
			</td>            
			</tr>		
		</table>  		
		
	<?php	
	}
	
	function pmc_post_builder_content(){	
		global $post;	
		$pmc_data = get_post_custom(get_the_id());		
		if (isset($pmc_data["custom_post_footer"][0])){		
			$custom_post_footer = $pmc_data["custom_post_footer"][0];	
		}else{		
			$custom_post_footer = "";	
		}	
		if (isset($pmc_data["custom_post_top"][0])){		
			$custom_post_top = $pmc_data["custom_post_top"][0];	
		}else{		
			$custom_post_top = "";	
		}	
		?>        
		<table cellpadding="15" cellspacing="0">
			<tr>            	
			<td><label>Custom Header for this Page (choose any template to be displayed as this Page's Header. If nothing is choosen, default header will be used.) : </label>				
			<br>		
				<select id="custom_post_top" name="custom_post_top">				
				<option value="none">Default</option>	
				<option value="empty" <?php if($custom_post_top == 'empty') echo 'selected'; ?>>Empty</option>	
				<?php						
				$args = array( 'numberposts' => -1,'post_type' => 'template');				
				$templates = get_posts($args);								
				foreach( $templates as $template ) : setup_postdata($template); ?>						
				<option value="<?php echo $template->ID; ?>" <?php if($template->ID == $custom_post_top) echo 'selected'; ?>><?php echo get_the_title($template->ID); ?></option>				
				<?php endforeach; ?>				
				</select>
			</td>            
			</tr>			
			<tr>            	
			<td><label>Custom Footer for this Page (choose any template to be displayed as this Page's Footer. If nothing is choosen, default footer will be used.) : </label>				
			<br>				
				<select id="custom_post_footer"  name="custom_post_footer">				
				<option value="none">Default</option>	
				<option value="empty" <?php if($custom_post_footer == 'empty') echo 'selected'; ?>>Empty</option>					
				<?php														
				foreach( $templates as $template ) : setup_postdata($template); ?>						
				<option value="<?php echo $template->ID; ?>" <?php if($template->ID == $custom_post_footer) echo 'selected'; ?>><?php echo get_the_title($template->ID); ?></option>	
				</option>				
				<?php endforeach;  ?>				
				</select>
			</td>            
			</tr>		
		</table>    
	
		<?php	
		
	}
	
	function pmc_update_post_builder(){
		global $post;
		if($post){			
			if( isset($_POST["custom_post_top"]) ) {			
				update_post_meta($post->ID , "custom_post_top", $_POST["custom_post_top"]);		
			}	
			if( isset($_POST["custom_post_footer"]) ) {			
				update_post_meta($post->ID , "custom_post_footer", $_POST["custom_post_footer"]);		
			}					
			if( isset($_POST["page_builder"]) ) {			
				update_post_meta($post->ID, "page_builder", $_POST["page_builder"]);			
			}		
		}
	}
	add_action('save_post','function_save_var');
	function function_save_var()
	{
	  if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE )
		return $post_id;
	}	
	
	/* function for advertise block */
function pmc_advertiseBlock($speed = 100){
	global $pmc_data; 
	wp_enqueue_script('pmc_bxSlider');			
	?>
	<?php $rand = rand(0,999); ?>
	<script>
		jQuery(document).ready(function(){	  
		<?php if(count($pmc_data['advertiseimage'])> 5) { ?>
		// Slider
		var $slider = jQuery('.sliderAdvertise-<?php echo $rand ?>').bxSlider({
			maxSlides:5,
			minSlides:1,
			moveSlides:1,
			prevText : '<i class="fa fa-angle-left"></i>',
			nextText : '<i class="fa fa-angle-right"></i>',
			auto : true,
			easing : 'easeInOutQuint',
			pause : <?php echo $speed ?>,
			pager :false,
			controls: true,
		});
		<?php } ?> 
		 });
	</script>
	<div class="advertise">
		<div class="advertiseInner">
			<?php 
			if(isset($pmc_data['advertiseimage'])){
				$slides = $pmc_data['advertiseimage']; ?>
				<ul class="sliderAdvertise sliderAdvertise-<?php echo $rand ?>">
				<?php foreach ($slides as $slide) {  ?>
					<li>
					<?php
					  if($slide['url'] != '') :
							   
						 if($slide['link'] != '') : ?>
						   <a href="<?php echo $slide['link']; ?>"><img src="<?php echo $slide['url']; ?>" alt="<?php echo $slide['title'] ?>" /></a>
						<?php else: ?>
							<img src="<?php echo $slide['url']; ?>" alt="<?php echo $slide['title'] ?>" width="225px" height="132px"/>
						<?php endif; ?>
								
					<?php endif; ?>
					</li>
				<?php } ?>
				</ul>
			<?php } ?>	
		</div>
	</div>
	<?php
}
/*blog loop*/
function BlogLoop($limit = 100){
	?>
	<div class="entry">
		<div class = "meta">
			<div class="topLeftBlog">	
				<h2 class="title"><a href="<?php the_permalink() ?>" rel="bookmark" title="Permanent Link to <?php the_title_attribute(); ?>"><?php the_title(); ?></a></h2>
				<div class = "post-meta">
					<?php _e('By ','pmc-themes'); ?>
					<?php echo get_the_author_link() ?>
					<?php _e(' on ','pmc-themes'); ?>
					<span><?php the_time('F j, Y') ?></span>
				</div>
			</div>
			
			<div class="blogContent">
				<div class="blogcontent"><?php echo content($limit) ?></div>
				<a class="blogmore" href="<?php the_permalink() ?>"><?php _e('Read more','pmc-themes'); ?> </a>
			</div>
		</div>		
	</div>	
	<?php
}
/*custom excerpt*/
function excerpt($limit) {
      $excerpt = explode(' ', get_the_excerpt(), $limit);
      if (count($excerpt)>=$limit) {
        array_pop($excerpt);
        $excerpt = implode(" ",$excerpt).'...';
      } else {
        $excerpt = implode(" ",$excerpt);
      } 
      $excerpt = preg_replace('`\[[^\]]*\]`','',$excerpt);
      return $excerpt;
    }
function content($limit) {
      $content = explode(' ', get_the_content(), $limit);
      if (count($content)>=$limit) {
        array_pop($content);
        $content = implode(" ",$content).'...';
      } else {
        $content = implode(" ",$content);
      } 
      $content = preg_replace('/\[.*?\]/','', $content);
      $content = apply_filters('the_content', $content); 
      $content = str_replace(']]>', ']]&gt;', $content);
      return $content;
}
/*check if array is empty*/
function pmc_is_array_empty($arr){
  if(is_array($arr)){     
      foreach($arr as $key => $value){
          if(!empty($value) || $value != NULL || $value != ""){
              return true;
              break;//stop the process we have seen that at least 1 of the array has value so its not empty
          }
      }
      return false;
  }
}

function pmc_woo(){
	if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
		return true;
	}
}

if(pmc_woo() && PMC_SHOP){
	
	/*set header and footer*/
	remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
	remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);
	add_action('woocommerce_before_main_content', 'pmc_wrapper_start', 10);
	add_action('woocommerce_after_main_content', 'pmc_wrapper_end', 10);
	function pmc_wrapper_start() { 
		echo'
			<!-- main content start -->
			<div class="mainwrap">
				<div class="main clearfix">
					<div class="content fullwidth">
						<div class="postcontent">
							<div class="posttext">';
	
	}

	//This line ends the new "woogrid" section

	function pmc_wrapper_end() { 
		echo'				</div>
						</div>
					</div>
				</div>
			</div>';

	}
	
	
	
	/*add wishlist*/
	add_filter( 'woocommerce_before_shop_loop_item', 'pmc_custom_product_category' );
	function pmc_custom_product_category($product) {
		global $wpdb, $product;
		$metakey= get_post_meta( get_the_ID(), '_meta_key', true );
		if($metakey!= NULL) {

			return $product;

		 } else {
		if(class_exists( 'YITH_WCWL_Shortcode' )){
			echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
		}
	  }

	}

	
	add_filter('add_to_cart_fragments', 'woocommerce_header_add_to_cart_fragment');

	function woocommerce_header_add_to_cart_fragment( $fragments ) {
		global $woocommerce;
		ob_start();
		?>
			<div class="header-cart-left">
				<div class="header-cart-items">
					<a href="<?php echo $cart; ?>" class="cart-top"><?php   _e('Items', 'pmc-themes');  ?></a>
					<a class="cart-bubble cart-contents">(<?php echo sprintf(_n('%d', '%d', $woocommerce->cart->cart_contents_count, 'pmc-themes'), $woocommerce->cart->cart_contents_count);?>)</a>
				</div>
				<div class="header-cart-total">
					<a class="cart-total"><?php echo $woocommerce->cart->get_cart_total(); ?></a>
				</div>
			</div>

		<?php

		$fragments['.header-cart-left'] = ob_get_clean();
		return $fragments;
	}


			
	
}
/*builder menu*/
class pmc_Walker_Builder extends Walker_Nav_Menu
{
	  function start_el(&$output, $item, $depth = 0, $args = array(), $id = 0) {
		   global $wp_query;
		   $attributes = '';
		   $indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
		   $class_names = $value = '';
		   $classes = empty( $item->classes ) ? array() : (array) $item->classes;
		   $class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
		   $class_names = ' class="'. esc_attr( $class_names ) . '"';
		   $output .= $indent . '<li id="menu-item-'.rand(0,9999).'-'. $item->ID . '"' . $value . $class_names .'>';
		   $attributes_title  = ! empty( $item->attr_title ) ? ' <i class="fa '  . esc_attr( $item->attr_title ) .'"></i>' : '';
		   $attributes .= ! empty( $item->url )        ? ' href="'   . 								esc_url(add_query_arg(
									array(
										'page' => 'aq-page-builder', 
										'action' => 'edit',
										'template' => $item->object_id,
									),
									admin_url( 'themes.php' )
								)) .'"' : '';
		   
		   $prepend = '';
		   $append = '';
		   if($depth != 0)
		   {
				$append = $prepend = "";
		   }
			$item_output = $args->before;
			$item_output .= '<a '. $attributes .'>';
			$item_output .= $attributes_title.$args->link_before .$prepend.apply_filters( 'the_title', $item->title, $item->ID ).$append;
			$item_output .= $args->link_after;
			$item_output .= '</a>';	
			$item_output .= $args->after;
			$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}
}



/*create shortcode*/
function pmc_shortcode_generator(){
$rand = rand(0,999);
?>
<div id="select-shorcode-add">
</div>
<div id="select-shortcode"class="select-shortcode">
	<div class="font-awesome-help">For icons name go to <a target="_blank" href="http://fontawesome.io/icons/">Font Awesome</a>. Use name like fa-button-name.</div>
	<div class="shortcode-help">Need <b>quick help</b> for shorcode?</div>
	<div id="remove" class="builderremove-<?php echo $rand ?>" data-option-key="filter">
		<a class="catlink" href="#filter" data-option-value="*">Show All</a>
		<a class="catlink" href="#filter" data-option-value=".columns">Columns</a>
		<a class="catlink" href="#filter" data-option-value=".buttons">Buttons</a>
		<a class="catlink" href="#filter" data-option-value=".list">List elements</a>
		<a class="catlink" href="#filter" data-option-value=".text">Text & Image elements</a>	
		<a class="catlink" href="#filter" data-option-value=".alert">Alert boxes</a>
		<a class="catlink" href="#filter" data-option-value=".toggle">Toogle elements</a>
		<a class="catlink" href="#filter" data-option-value=".premium-shortcode">Premium shortcode</a>
		<a class="catlink" href="#filter" data-option-value=".ecommerce">Ecommerce shortcode</a>		
	</div>			
	<div id="shortcodes_buttons" class="shortcodes_buttons">
		<!-- columns-->
		<a class="shortcode-buttons columns rand-<?php echo $rand ?>" data-category="columns" id="one_half" title="Half column"><i class="fa fa-columns"></i>Half</a>
		<a class="shortcode-buttons columns rand-<?php echo $rand ?>" data-category="columns"  id="one_half_last" title="Half column last"><i class="fa fa-columns"></i>Half last</a>
		<a class="shortcode-buttons columns rand-<?php echo $rand ?>" data-category="columns"  id="one_third" title="Third column"><i class="fa fa-columns"></i>One third</a>
		<a class="shortcode-buttons columns rand-<?php echo $rand ?>" data-category="columns"  id="one_third_last" title="Third column last"><i class="fa fa-columns"></i>Third last</a>
		<a class="shortcode-buttons columns rand-<?php echo $rand ?>" data-category="columns"  id="two_thirds" title="Two thirds column"><i class="fa fa-columns"></i>Two thirds </a>
		<a class="shortcode-buttons columns rand-<?php echo $rand ?>" data-category="columns"  id="two_thirds_last" title="Two thirds column last"><i class="fa fa-columns"></i>Two thirds last</a>
		<a class="shortcode-buttons columns rand-<?php echo $rand ?>" data-category="columns"  id="one_fourth" title="One fourth column "><i class="fa fa-columns"></i>One fourth </a>	
		<a class="shortcode-buttons columns rand-<?php echo $rand ?>" data-category="columns"  id="one_fourth_last" title="One fourth column last"><i class="fa fa-columns"></i>One four. last</a>	
		<a class="shortcode-buttons columns rand-<?php echo $rand ?>" data-category="columns"  id="three_fourths" title="Three Fourths column"><i class="fa fa-columns"></i>Three Fourths </a>
		<a class="shortcode-buttons columns rand-<?php echo $rand ?>" data-category="columns"  id="three_fourths_last" title="Two thirds column last"><i class="fa fa-columns"></i>Three fourt. last</a>
		<a class="shortcode-buttons columns rand-<?php echo $rand ?>" data-category="columns"  id="one_fifth" title="One Fifth column"><i class="fa fa-columns"></i>One Fifth</a>	
		<a class="shortcode-buttons columns rand-<?php echo $rand ?>" data-category="columns"  id="one_fifth_last" title="One Fifth Last column"><i class="fa fa-columns"></i>One Fifth Last</a>				
		<!-- buttons -->
		<a class="shortcode-buttons buttons rand-<?php echo $rand ?>" data-category="buttons" id="button_simple" title="Simple Button"><i class="fa fa-circle"></i>Simple button</a>
		<a class="shortcode-buttons buttons rand-<?php echo $rand ?>" data-category="buttons" id="button_simple_icon" title="Simple button with icon"><i class="fa fa-picture-o"></i>Simple with icon</a>				
		<a class="shortcode-buttons buttons rand-<?php echo $rand ?>" data-category="buttons" id="button_icon" title="Button with icon and text"><i class="fa fa-picture-o"></i>Button with icon</a>
		<a class="shortcode-buttons buttons rand-<?php echo $rand ?>" data-category="buttons" id="button_only_icon" title="Button with icon"><i class="fa fa-picture-o"></i>Button only icon</a>				
		<a class="shortcode-buttons buttons rand-<?php echo $rand ?>" data-category="buttons" id="button_round" title="Round button"><i class="fa fa-square"></i>Round button</a>	
		<a class="shortcode-buttons buttons rand-<?php echo $rand ?>" data-category="buttons" id="button_social" title="Social button"><i class="fa fa-group"></i>Social button</a>
		<a class="shortcode-buttons buttons rand-<?php echo $rand ?>" data-category="buttons" id="button_simple_double" title="Simple double Button"><i class="fa fa-th-large"></i>Double button</a>
		<a class="shortcode-buttons buttons rand-<?php echo $rand ?>" data-category="buttons" id="button_icon_double" title="Icon double Button"><i class="fa fa-th-large"></i>Doub. icon button</a>				
		<!-- lists -->
		<a class="shortcode-buttons list rand-<?php echo $rand ?>" data-category="list" id="list_arrow" title="List arrow"><i class="fa fa-cloud-download"></i>List arrow</a>
		<a class="shortcode-buttons list rand-<?php echo $rand ?>" data-category="list"  id="list_link" title="Link List"><i class="fa fa-cloud-download"></i>Link List</a>
		<a class="shortcode-buttons list rand-<?php echo $rand ?>" data-category="list"  id="list_image" title="Image List"><i class="fa fa-cloud-download"></i>Image List</a>
		<a class="shortcode-buttons list rand-<?php echo $rand ?>" data-category="list"  id="list_star" title="Star List"><i class="fa fa-cloud-download"></i>Star List</a>
		<a class="shortcode-buttons list rand-<?php echo $rand ?>" data-category="list"  id="list_settings" title="Settings List"><i class="fa fa-cloud-download"></i>Settings List </a>
		<a class="shortcode-buttons list rand-<?php echo $rand ?>" data-category="list" id="list_ribbon" title="Ribbon List"><i class="fa fa-cloud-download"></i>Ribbon List</a>
		<a class="shortcode-buttons list rand-<?php echo $rand ?>" data-category="list" id="list_plus" title="Plus List"><i class="fa fa-cloud-download"></i>Plus List</a>	
		<a class="shortcode-buttons list rand-<?php echo $rand ?>" data-category="list"  id="list_mail" title="Mail List"><i class="fa fa-cloud-download"></i>Mail List</a>	
		<a class="shortcode-buttons list rand-<?php echo $rand ?>" data-category="list"  id="list_tick" title="TickList"><i class="fa fa-cloud-download"></i>TickList</a>
		<a class="shortcode-buttons list rand-<?php echo $rand ?>" data-category="list"  id="list_comment" title="Comment List"><i class="fa fa-cloud-download"></i>Comment List</a>	
		<a class="shortcode-buttons list rand-<?php echo $rand ?>" data-category="list"  id="list_arrow_point" title="Arrow Point List"><i class="fa fa-cloud-download"></i>Arrow Point List</a>			
		<!-- text elements -->
		<a class="shortcode-buttons text icon rand-<?php echo $rand ?>" data-category="text" id="pmc_icon" title="Icon"><i class="fa fa-picture-o"></i>Icon with link</a>	
		<a class="shortcode-buttons text premium-shortcode icon rand-<?php echo $rand ?>" data-category="text premium-shortcode" id="pmc_box_icon" title="Icon Box"><i class="fa fa-pencil-square-o"></i>Icon Box</a>
		<!-- alert boxes -->
		<a class="shortcode-buttons alert rand-<?php echo $rand ?>" data-category="alert" id="box_1" title="Info Box"><i class="fa fa-info-circle"></i>Info Box</a>
		<a class="shortcode-buttons alert rand-<?php echo $rand ?>" data-category="alert"  id="box_2" title="Successs Box"><i class="fa fa-info-circle"></i>Successs Box</a>
		<a class="shortcode-buttons alert rand-<?php echo $rand ?>" data-category="alert"  id="box_3" title="Question Box"><i class="fa fa-info-circle"></i>Question Box</a>	
		<a class="shortcode-buttons alert rand-<?php echo $rand ?>" data-category="alert"  id="box_4" title="Error Box"><i class="fa fa-info-circle"></i>Error Box</a>
		<a class="shortcode-buttons text rand-<?php echo $rand ?>" data-category="text" id="dropcap" title="Drop Cap"><i class="fa fa-bold"></i>Drop Cap</a>
		<a class="shortcode-buttons text rand-<?php echo $rand ?>" data-category="text" id="pmc_box" title="Box"><i class="fa fa-pencil-square-o"></i>Box</a>				
		<a class="shortcode-buttons text rand-<?php echo $rand ?>" data-category="text" id="break" title="Break"><i class="fa fa-chain-broken"></i>Break</a>	
		<a class="shortcode-buttons text rand-<?php echo $rand ?>" data-category="text" id="break_line" title="Break with line"><i class="fa fa-chain-broken"></i>Break with line</a>					
		<a class="shortcode-buttons text rand-<?php echo $rand ?>" data-category="text" id="pmc_quote" title="Quote"><i class="fa fa-quote-left"></i>Quote</a>				
		<!-- toggle elements -->
		<a class="shortcode-buttons toggle rand-<?php echo $rand ?>" data-category="toggle" id="progressbar" title="Progress bar"><i class="fa fa-cloud-download"></i>Progress bar</a>
		<a class="shortcode-buttons toggle rand-<?php echo $rand ?>" data-category="toggle"  id="accordion" title="Accordion"><i class="fa fa-tasks"></i>Accordion</a>
		<a class="shortcode-buttons toggle rand-<?php echo $rand ?>" data-category="toggle"  id="tabs" title="Tabs"><i class="fa fa-tasks"></i>Tabs</a>	
		<a class="shortcode-buttons toggle rand-<?php echo $rand ?>" data-category="toggle"  id="toggle" title="Toggle"><i class="fa fa-long-arrow-right"></i>Toggle</a>	
		<!-- toggle elements -->
		<a class="shortcode-buttons text premium-shortcode image resp_lightbox rand-<?php echo $rand ?>" data-category="text premium-shortcode" id="lightbox" title="Lightbox Image"><i class="fa fa-picture-o"></i>Lightbox Image</a>
		<a class="shortcode-buttons text premium-shortcode image rand-<?php echo $rand ?>" data-category="text premium-shortcode" id="pmc_image" title="Animated image with texton hover"><i class="fa fa-picture-o"></i>Animated image</a>
		<a class="shortcode-buttons text premium-shortcode image rand-<?php echo $rand ?>" data-category="text premium-shortcode" id="image_circle_1" title="Animated image with heading on hover"><i class="fa fa-picture-o"></i>Animated <span class="circle-text">&#9675;</span> img.</a>
		<a class="shortcode-buttons text premium-shortcode image rand-<?php echo $rand ?>" data-category="text premium-shortcode" id="image_square_1" title="Animated image with heading on hover"><i class="fa fa-picture-o"></i>Animated <span class="square-text">&#9607; </span> img.</a>
		<a class="shortcode-buttons premium-shortcode rand-<?php echo $rand ?>" data-category="premium-shortcode"  id="pricing_tables" title="Pricing table"><i class="fa fa-table"></i>Pricing table</a>
		<a class="shortcode-buttons premium-shortcode rand-<?php echo $rand ?>" data-category="premium-shortcode"  id="pricing_tables_icon" title="Pricing table"><i class="fa fa-table"></i>Icon pric. table</a>
		<a class="shortcode-buttons premium-shortcode rand-<?php echo $rand ?>" data-category="premium-shortcode"  id="pricing_tables_circle" title="Pricing table with circle"><i class="fa fa-table"></i>Circle pric. table</a>
		<a class="shortcode-buttons premium-shortcode rand-<?php echo $rand ?>" data-category="premium-shortcode"  id="pricing_tables_white" title="White pricing table"><i class="fa fa-table"></i>White pric. table</a>
		<a class="shortcode-buttons toggle premium-shortcode rand-<?php echo $rand ?>" data-category="toggle premium-shortcode" id="pmc_progress_circle" title="Progress circle"><i class="fa fa-cloud-download"></i>Progress circle</a>					
		<a class="shortcode-buttons premium-shortcode rand-<?php echo $rand ?>" data-category="premium-shortcode"  id="count_block" title="Count block"><i class="fa fa-table"></i>Count block</a>					
		<a class="shortcode-buttons premium-shortcode rand-<?php echo $rand ?>" data-category="premium-shortcode"  id="count_block_simple" title="Count block Simple"><i class="fa fa-table"></i>Simple count b.</a>	
		<a class="shortcode-buttons premium-shortcode rand-<?php echo $rand ?>" data-category="premium-shortcode"  id="google_map" title="Google map"><i class="fa fa-map-marker"></i>Google map</a>
		<a class="shortcode-buttons premium-shortcode rand-<?php echo $rand ?>" data-category="premium-shortcode"  id="google_map_more" title="Google map more markers"><i class="fa fa-map-marker"></i>G. map > markers</a>		
		<a class="shortcode-buttons premium-shortcode rand-<?php echo $rand ?>" data-category="premium-shortcode"  id="scroll_link" title="Scroll link"><i class="fa fa-link"></i>Scroll link</a>		
		<?php if(pmc_woo() && PMC_SHOP){ ?>
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce" id="woocommerce_cart" title="Woocommerce cart"><i class="fa fa-shopping-cart"></i>Woo. cart</a>
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce" id="woocommerce_checkout" title="Woocommerce checkout"><i class="fa fa-shopping-cart"></i>Woo. checkout</a>
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce" id="woocommerce_order_tracking" title="Woocommerce order tracking"><i class="fa fa-shopping-cart"></i>Woo. order tra.</a>
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce" id="woocommerce_my_account" title="Woocommerce account"><i class="fa fa-shopping-cart"></i>Woo. account</a>
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="recent_products" title="Woo. recent prod."><i class="fa fa-shopping-cart"></i>Woo. recent prod.</a>
		<!--<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="featured_products" title="Woo. featu. prod."><i class="fa fa-shopping-cart"></i>Woo. featu. prod.</a>-->
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="product_sku" title="Woo. product by sku"><i class="fa fa-shopping-cart"></i>Woo. prod by sku</a>
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="product_id" title="Woo. product by id"><i class="fa fa-shopping-cart"></i>Woo. prod. by ID</a>
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="products_id" title="Woo. products by ID's"><i class="fa fa-shopping-cart"></i>Woo. prod. by ID's</a>
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="products_sku" title="Woo. products by sku's"><i class="fa fa-shopping-cart"></i>Prod. by SKU's</a>				
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="add_to_cart_id" title="Woo. add to cart by ID"><i class="fa fa-shopping-cart"></i>Woo.->cart by ID</a>	
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="add_to_cart_sku" title="Woo. add to cart by SKU"><i class="fa fa-shopping-cart"></i>Woo.->cart by SKU</a>					
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce" id="add_to_cart_url_id" title="Woo. add to cart URL by ID"><i class="fa fa-shopping-cart"></i>Link to cart by ID</a>	
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce" id="add_to_cart_url_sku" title="Woo. add to cart URL by SKU"><i class="fa fa-shopping-cart"></i>Link to cart by SKU</a>	
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="product_page_id" title="Single product page by ID"><i class="fa fa-shopping-cart"></i>Prod. page by ID</a>
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="product_page_sku" title="Single product page by SKU"><i class="fa fa-shopping-cart"></i>Prod. page by SKU</a>				
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="product_category" title="Product category"><i class="fa fa-shopping-cart"></i>Prod. category</a>	
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="product_categories" title="Product categories"><i class="fa fa-shopping-cart"></i>Prod. categories</a>					
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="sale_products" title="Product on sale"><i class="fa fa-shopping-cart"></i>On sale prod.</a>	
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="best_selling_products" title="Best selling product"><i class="fa fa-shopping-cart"></i>Best seller</a>			
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="top_rated_products" title="Top rated products"><i class="fa fa-shopping-cart"></i>Top rat. prod.</a>					
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="product_attribute" title="Product attributes"><i class="fa fa-shopping-cart"></i>Prod. attributes</a>	
		<a class="shortcode-buttons ecommerce rand-<?php echo $rand ?>" data-category="ecommerce"  id="related_products" title="Related product"><i class="fa fa-shopping-cart"></i>Related prod.</a>					
		<?php } ?>		
	</div>				
</div>
<?php
}
	
}
